library(statnet)

load("grey.RData")
g <- gray

list.vertex.attributes(g)       #attributs des sommets
get.vertex.attribute(g, "position") #modalités des attributs

X11()
plot(g, vertex.col=c("blue","pink")
     [1+(get.vertex.attribute(g, "sex")=="F")], displaylabels=TRUE)

#approche basique : simuler x graphes et comparer une propriété (ici distribution des degrés)

graphs <- rgraph(44, m = 1000, tprob = gden(g)) #simulation 1000 graphes, même nombre de sommets
#même densité
deg <- apply(graphs, 1, degree)

par(mfrow=c(1,2))
hist(degree(g), xlim=c(0,15), breaks=20, main = "Degré observé")
hist(deg, xlim=c(0,15), breaks=10, main = "Degré simulé")

#modèle ergm

?ergm.terms   #paramètres possibles
?control.ergm #options pour les méthodes d'estimation

#modèle de base : nombre de liens et tendance à l'hétérosexualité
g.base<-ergm(g ~ edges + nodematch("sex")) #estimation du modèle
summary(g.base)                            #propriétés du modèle


#2 paramètres significatifs
#proba qu'il y ait un lien : exp(-2.30)/(1+exp(-2.30)), or 0.09 (densité faible)
#proba en log qu'il y ait un lien homosexuel : -2.30-3.14 = -5.44
#proba : exp(-5.44)/(1+exp(-5.44)) = 0.004

par(mfrow=c(1,1))
plot(simulate(g.base),
     vertex.col=c("blue","pink")[1+(get.vertex.attribute(g, "sex")=="F")])

#simulation du modèle montre une différence majeure : le grand nombre d'isolés
#vérification via la qualité d'ajustement

g.base.gof <- gof(g.base)
summary(g.base.gof)    #résumé

#les graphes générés ont en moyenne 5 sommets de degré 0
#Goodness-of-fit for degree 
#   obs min  mean max MC p-value
#0   0   1  4.89  11       0.00
#1  24   5 11.01  23       0.00

par(mfrow=c(3,1))       #fenêtre graphique : 3 lignes, 1 colonne
plot(g.base.gof)

par(mfrow=c(1,1))  #ligne droite : graphe étudié ; box plot : graphes simulés
#distance geodesic NR : non reachable (composantes connexes)

#tendance à la monogamie ?
plot(table(degree(g)/2))
#pourquoi diviser par 2 : sinon considère qu'un lien est en fait un lien entrant + un sortant

g.base1<-ergm(g ~ edges + nodematch("sex") + degree(1))
summary(g.base1)  #beaucoup plus performant : cf AIC et BIC
par(mfrow=c(1,1))
plot(simulate(g.base1),
     vertex.col=c("blue","pink")[1+(get.vertex.attribute(g, "sex")=="F")]) #plus d'isolés

#goodness of fit
g.base1.gof<-gof(g.base1)
summary(g.base1.gof)

#Goodness-of-fit for degree 

#   obs min  mean max MC p-value
#0    0   0  0.68   3       1.00

par(mfrow=c(3,1))
plot(g.base1.gof) #voir la courbe du degré

mcmc.diagnostics(g.base1) #caractéristiques des graphes simulés avec modèle

#rôle de l'âge ?

g.base2<-ergm(g~edges+nodematch("sex")+degree(1)+absdiff("birthyear"),
              control=control.ergm(MCMC.burnin=50000, MCMC.interval=5000))
summary(g.base2) #modèle plus performant (cf AIC  et BIC)

#visualisation
par(mfrow=c(1,1))
plot(simulate(g.base2),
     vertex.col=c("blue","pink")[1+(get.vertex.attribute(g, "sex")=="F")]) #?

#goodness of fit
g.base2.gof<-gof(g.base2)
summary(gof(g.base2))

par(mfrow=c(3,1))
plot(g.base2.gof)

mcmc.diagnostics(g.base2)
